[![Build Status](https://travis-ci.org/dxflores/invis.svg?branch=master)](https://travis-ci.org/dxflores/invis)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/2d318652634a424eaddd354be41b114d)](https://www.codacy.com/manual/dxflores/invis?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=dxflores/invis&amp;utm_campaign=Badge_Grade)
[![codecov](https://codecov.io/gh/dxflores/invis/branch/master/graph/badge.svg)](https://codecov.io/gh/dxflores/invis)

# Invis

Invis is an invisible framework which purpose is to enforce type checking of both builtins as well as user defined types at **runtime**. 
It is distributed as a single file with no extra dependencies other than the Python Standard Library (>= 3.7).

To install: `pip install invis`

A comprehensive tutorial on how to use the framework can be found
[here](https://github.com/dxflores/invis/tree/master/examples/tutorial.md)

A discussion about the project, held on reddit's algotrading subforum, can be found [here](https://www.reddit.com/r/algotrading/comments/dwrk59/a_micro_framework_to_give_you_peace_of_mind_with/)
